//  Данный скетч демонстрирует работу Trema-модуля bluetooth в режиме ведущего (master)
//  Модуль ищет имена и адреса всех bluetooth устройств в радиусе действия
//  Библиотека написана http://iarduino.ru только для Trema-модулей bluetooth и не будет работать с другими модулями

#include <SoftwareSerial.h>                // Подключаем библиотеку SoftwareSerial для общения с модулем по программной шине UART
#include <iarduino_Bluetooth_HC05.h>       // Подключаем библиотеку iarduino_Bluetooth_HC05 для работы с модулем
SoftwareSerial softSerial(2,3);            // Создаём объект softSerial указывая выводы RX, TX (можно указывать любые выводы Arduino UNO)
                                           // - назначенный вывод RX Arduino (в данном примере вывод 2) подключается к выводу TX модуля
                                           // - назначенный вывод TX Arduino (в данном примере вывод 3) подключается к выводу RX модуля
iarduino_Bluetooth_HC05 hc05(4);           // Создаём объект hc05 указывая любой вывод Arduino. Назначенный вывод подключается к выводу K модуля
int i;                                     // Объявляем переменную для вывода результатов работы функций

void setup(){
//  Инициируем передачу данных по аппаратной шине UART для вывода результата в монитор
    Serial.begin(9600);
//  Инициируем работу с модулем hc05, указывая объект UART через который осуществляется связь
    i=hc05.begin(softSerial);
    Serial.print("begin: "); if(i){Serial.println("Ok");} else {Serial.println("Error");}
}                                        

//  Инициализация модуля hc05.begin(); может занять несколько секунд
//  В этом примере модуль подключается через программный UART используя библиотеку SoftwareSerial, а при инициализации работы с модулем hc05.begin() указывается объект softSerial
//  Но модуль можно подключать и к аппаратному UART, тогда при инициализации работы с модулем hc05.begin() нужно указать Serial или (для ArduinoMega) Serial1, Serial2, Serial3.

void loop (){
//  Выполняем поиск устройств, не дольше 10 секунд:
    i=hc05.find(10);
//  Выводим результаты поиска:
    if(i){
        Serial.print("found "); Serial.print(i); Serial.println(" devices:");
        for(int j=0; j<i; j++){
            Serial.print(j+1); Serial.print(") Name: "); Serial.print(hc05.findName[j]); Serial.print(", Address: "); Serial.print(hc05.findAddr[j]); Serial.println(";");
        }
    }else{
        Serial.println("Device not found.");
    }
//  Ждём 1 секунду
    delay(1000);
}

//  Функция hc05.find(время); возвращает количество найденных устройств, а принимает время в секундах, это таймаут после которого требуется прекратить поиск.
//  Если устройства найдены, то функция затратит еще несколько секунд (свыше таймаута) для их опроса.
//  Все найденные имена устройств сохраняются в массив hc05.findName, а адреса устройств в массив hc05.findAddr
//  Индексы обоих массивов совпадают, это значит что:
//  - имя 1 устройства находится в hc05.findName[0], а его адрес в hc05.findAddr[0]
//  - имя 2 устройства находится в hc05.findName[1], а его адрес в hc05.findAddr[1]
//  и т.д.
//  Данной функцией можно найти не более 5 устройств. Если до таймаута найдены все 5 устройств, то функция выполнится быстрее таймаута.